import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["時々、複数の ", jsx(_components.code, {
        children: "Suspense"
      }), " コンポーネントを連携したい場合があります。1 つのアプローチとして、すべてを単一の ", jsx(_components.code, {
        children: "Suspense"
      }), " の下に置くことが考えられますが、それでは、単一のローディング動作に制限されてしまいます。フォールバックの状態が 1 つということは、最後のものがロードされるまで、すべてのものが常に待つ必要があるということです。その代わりに、Solid は ", jsx(_components.code, {
        children: "SuspenseList"
      }), " コンポーネントを導入して、これを連携します。"]
    }), "\n", jsxs(_components.p, {
      children: ["今回の例のように、複数の ", jsx(_components.code, {
        children: "Suspense"
      }), " コンポーネントがあるとします。これらを ", jsx(_components.code, {
        children: "revealOrder"
      }), " に ", jsx(_components.code, {
        children: "forwards"
      }), " を設定した ", jsx(_components.code, {
        children: "SuspenseList"
      }), " でラップすると、ロードされる順番に関係なく、ツリーに表示される順番にレンダリングされます。これにより、ページのジャンプを減らすことができます。", jsx(_components.code, {
        children: "revealOrder"
      }), " を ", jsx(_components.code, {
        children: "backwards"
      }), " や ", jsx(_components.code, {
        children: "together"
      }), " に設定すると、それぞれ順序を逆にしたり、すべてのサスペンスコンポーネントがロードされるのを待つことができます。さらに、", jsx(_components.code, {
        children: "tail"
      }), " オプションがあり、", jsx(_components.code, {
        children: "hidden"
      }), " や ", jsx(_components.code, {
        children: "collapsed"
      }), " に設定できます。これは、すべてのフォールバックを表示するというデフォルトの動作をオーバーライドして、何も表示しないか、または ", jsx(_components.code, {
        children: "revealOrder"
      }), " で設定した方向に次のフォールバックを表示します。"]
    }), "\n", jsxs(_components.p, {
      children: ["現在の例では、ローディングのプレースホルダーに関しては少し混乱しています。すべてのデータを独立してロードしていますが、データがロードされる順番に応じて、複数のプレースホルダーを表示しています。それでは、", jsx(_components.code, {
        children: "ProfilePage"
      }), " コンポーネントの JSX を", jsx(_components.code, {
        children: "<SuspenseList>"
      }), " でラップしてみましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), " revealOrder=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"forwards\""
        }), " tail=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"collapsed\""
        }), ">\n  ", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileDetails"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "user"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.user}"
            }), " />"]
          })
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading posts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTimeline"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "posts"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.posts}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading fun facts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTrivia"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "trivia"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.trivia}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), ">\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-5cc2d8a7.js.map
