import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    pre: "pre",
    code: "code",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Производительность Solid отчасти объясняется тем, что наши компоненты в основном представляют собой просто вызовы функций. Способ распространения обновлений заключается в том, что компилятор оборачивает потенциально реактивные выражения в геттеры объектов. Вы можете представить вывод компилятора:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-comment",
          children: "// этот JSX"
        }), "\n<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), " dynamic={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "mySignal"
        }), "()}>\n\t", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Child"
            }), " />"]
          })
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), ">;\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// превращается в:"
        }), "\n", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), "({\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "get"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "dynamic"
        }), "() {\n\t\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "mySignal"
        }), "();\n\t},\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "get"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "children"
        }), "() {\n\t\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Child"
        }), "();\n\t},\n});\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Это означает, что эти пропсы вычисляются лениво — в момент вызова. Это сохраняет реактивность без добавления посторонних оберток или синхронизации. Однако это означает, что повторный доступ может привести к созданию лишних потомков (", jsx(_components.code, {
        children: "children"
      }), "): компонентов или элементов."]
    }), "\n", jsx(_components.p, {
      children: "В подавляющем большинстве случаев вы просто вставляете пропсы в JSX, поэтому проблем нет. Однако, когда вы работаете с потомками, есть опасность создать их по несколько раз."
    }), "\n", jsxs(_components.p, {
      children: ["Поэтому у Solid есть ", jsx(_components.code, {
        children: "children"
      }), " хелпер (", jsx(_components.code, {
        children: "helper"
      }), "). Этот метод создает ", jsx(_components.code, {
        children: "Memo"
      }), " вокруг свойства ", jsx(_components.code, {
        children: "children"
      }), " и управляет любыми вложенными дочерние реактивными ссылками, так что вы можете напрямую взаимодействовать с дочерними элементами."]
    }), "\n", jsxs(_components.p, {
      children: ["В этом примере у нас есть динамический список, и мы хотим установить свойство стиля элементов ", jsx(_components.code, {
        children: "color"
      }), ". Если бы мы напрямую взаимодействовали с ", jsx(_components.code, {
        children: "props.children"
      }), ", мы не только создавали бы узлы несколько раз, но и обнаружили бы, что", jsx(_components.code, {
        children: " props.children"
      }), " является функцией, которую ", jsx(_components.code, {
        children: "Memo"
      }), " возвращает из ", jsx(_components.code, {
        children: "<For>"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Вместо этого давайте воспользуемся хелпером ", jsx(_components.code, {
        children: "children"
      }), " внутри ", jsx(_components.code, {
        children: "color-list.tsx"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "ColoredList"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " c = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "children"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " props.", jsx(_components.span, {
          className: "hljs-property",
          children: "children"
        }), ");\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsx(_components.span, {
            className: "hljs-tag",
            children: "<>"
          }), "{c()}", jsx(_components.span, {
            className: "hljs-tag",
            children: "</>"
          })]
        }), ";\n}\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Теперь, чтобы обновить наши элементы, давайте создадим ", jsx(_components.code, {
        children: "Эффект"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-title function_",
          children: "createEffect"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "c"
        }), "().", jsx(_components.span, {
          className: "hljs-title function_",
          children: "forEach"
        }), "(", jsxs(_components.span, {
          className: "hljs-function",
          children: [jsx(_components.span, {
            className: "hljs-params",
            children: "item"
          }), " =>"]
        }), " (item.", jsx(_components.span, {
          className: "hljs-property",
          children: "style"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "color"
        }), " = props.", jsx(_components.span, {
          className: "hljs-property",
          children: "color"
        }), ")));\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-694469f3.js.map
