import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    pre: "pre",
    code: "code",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Solid의 성능을 높이는 부분 중 하나는 컴포넌트가 기본적으로 함수 호출이기 때문입니다. 컴파일러가 객체의 getter 안에서 잠재적으로 리액티브한 표현식을 래핑하는 방식으로 업데이트를 전파합니다. 컴파일 결과를 다음과 같이 그려볼 수 있습니다:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-comment",
          children: "// 이 JSX 표현식이"
        }), "\n<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), " dynamic={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "mySignal"
        }), "()}>\n  ", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Child"
            }), " />"]
          })
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), ">\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// 이렇게 컴파일됩니다."
        }), "\n", jsx(_components.span, {
          className: "hljs-title class_",
          children: "MyComp"
        }), "({\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "get"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "dynamic"
        }), "() { ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "mySignal"
        }), "() },\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "get"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "children"
        }), "() { ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Child"
        }), "() }\n});\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "이는 props가 지연 평가됨을 의미합니다. props에 대한 액세스는 사용될 때까지 연기됩니다. 이로 인해 추가 래퍼나 동기화를 도입하지 않으면서도 반응성을 유지할 수 있습니다. 하지만, 반복적인 액세스로 인해 자식 컴포넌트나 엘리먼트가 다시 생성될 수 있음을 의미하기도 합니다."
    }), "\n", jsx(_components.p, {
      children: "대부분의 경우 JSX에 props를 삽입하기 때문에 문제가 없습니다만, 자식 컴포넌트 관련 작업에서는 자식들이 여러 번 생성되지 않도록 주의할 필요가 있습니다."
    }), "\n", jsxs(_components.p, {
      children: ["이러한 이유로, Solid는 ", jsx(_components.code, {
        children: "children"
      }), " 헬퍼를 제공합니다. 이 메서드는 ", jsx(_components.code, {
        children: "children"
      }), " prop 에 대해 memo를 생성하고, 자식과 직접 인터랙션을 할 수 있도록 중첩된 자식들에 대해서도 리액티브한 참조를 제공합니다."]
    }), "\n", jsxs(_components.p, {
      children: ["예제에서는, 동적 리스트에 있는 각 항목의 ", jsx(_components.code, {
        children: "color"
      }), " 스타일 속성을 설정하려고 합니다. ", jsx(_components.code, {
        children: "props.children"
      }), "와 직접 인터랙션을 하게 되면, 노드가 여러 번 생성될 뿐만 아니라 ", jsx(_components.code, {
        children: "props.children"
      }), "이 ", jsx(_components.code, {
        children: "<For>"
      }), "에서 반환된 Memo인 함수임을 알 수 있습니다."]
    }), "\n", jsxs(_components.p, {
      children: ["대신 ", jsx(_components.code, {
        children: "colored-list.tsx"
      }), " 파일 내부에서 ", jsx(_components.code, {
        children: "children"
      }), " 헬퍼를 사용해 보겠습니다:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "ColoredList"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " c = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "children"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " props.", jsx(_components.span, {
          className: "hljs-property",
          children: "children"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsx(_components.span, {
            className: "hljs-tag",
            children: "<>"
          }), "{c()}", jsx(_components.span, {
            className: "hljs-tag",
            children: "</>"
          })]
        }), "\n}\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "이제 엘리먼트를 업데이트하기 위해 이펙트를 생성해 보겠습니다:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-title function_",
          children: "createEffect"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "c"
        }), "().", jsx(_components.span, {
          className: "hljs-title function_",
          children: "forEach"
        }), "(", jsxs(_components.span, {
          className: "hljs-function",
          children: [jsx(_components.span, {
            className: "hljs-params",
            children: "item"
          }), " =>"]
        }), " item.", jsx(_components.span, {
          className: "hljs-property",
          children: "style"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "color"
        }), " = props.", jsx(_components.span, {
          className: "hljs-property",
          children: "color"
        }), "));\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-6b13e12f.js.map
