import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span",
    a: "a"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["Несмотря на то, что ", jsx(_components.code, {
        children: "lazy"
      }), " и ", jsx(_components.code, {
        children: "createResource"
      }), " могут быть использованы независимо, Solid имеет механизм для координации нескольких асинхронных событий. ", jsx(_components.code, {
        children: "Suspense"
      }), " позволяет нам показывать заглушку (", jsx(_components.code, {
        children: "fallback"
      }), "), до тех пор пока мы полностью не выполним асинхронные события в нашем компоненте."]
    }), "\n", jsxs(_components.p, {
      children: ["Это может улучшить пользовательский опыт, так как убирает лишнюю визуализацию данных в пограничных состояниях загрузки и скачки контента. ", jsx(_components.code, {
        children: "Suspense"
      }), " автоматически определяет все асинхронные чтения и координирует отрисовку. Вы можете использовать неограниченное количество ", jsx(_components.code, {
        children: "Suspense"
      }), " компонентов в вашем коде и только ближайший будет использовать заглушку, когда Solid найдет ближайший ", jsx(_components.code, {
        children: "loading"
      }), " ", jsx(_components.code, {
        children: "Сигнал"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Давайте добавим компонент ", jsx(_components.code, {
        children: "Suspense"
      }), " в наш пример с ленивой загрузкой (", jsx(_components.code, {
        children: "lazy loading"
      }), "):"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<>\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          }), "Welcome", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "p"
            }), ">"]
          }), "Loading...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "p"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Greeting"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "name"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"Jake\""
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</>\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Теперь при загрузке мы увидим нашу заглушку."
    }), "\n", jsxs(_components.p, {
      children: ["Очень важно понимать, что именно чтение асинхронного значения включает ", jsx(_components.code, {
        children: "Suspense"
      }), " в работу, а не сам факт запуска асинхронной операции. Если ", jsx(_components.code, {
        children: "Ресурс"
      }), " (включая ", jsx(_components.code, {
        children: "lazy"
      }), " компоненты) не имеет чтения внутри ", jsx(_components.code, {
        children: "Suspense"
      }), ", то он не будет активирован."]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Suspense"
      }), " можно представить как ", jsx(_components.code, {
        children: "Show"
      }), " компонент, который показывает обе ветки. Несмотря на то, что ", jsx(_components.code, {
        children: "Suspense"
      }), " является обязательным для асинхронного выполнения на сервере (", jsx(_components.code, {
        children: "server rendering"
      }), "), если вы используете Solid только для рендеринга на стороне клиента (", jsx(_components.code, {
        children: "client rendering"
      }), "), то использование ", jsx(_components.code, {
        children: "Suspense"
      }), " можно отложить. Модель детальной реактивности Solid позволяет нам разбивать наше приложение на любое количество файлов не увеличивая затрат по ресурсам."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "Deferred"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [resume, setResume] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "false"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "setTimeout"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setResume"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "true"
        }), "), ", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{resume()}"
            }), ">"]
          }), "{props.children}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), ">"]
          })]
        }), ";\n}\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Вся работа в Solid запускается независимо друг от друга изначально, поэтому в вещах вроде ", jsx(_components.a, {
        href: "https://ru.reactjs.org/blog/2018/03/01/sneak-peek-beyond-react-16.html",
        children: "Time Slicing"
      }), " нет необходимости."]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-ce44fd02.js.map
