import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["이제 ", jsx(_components.code, {
        children: "<For>"
      }), "를 사용해 Solid에서 리스트를 렌더링하는 방법을 알게 되었지만, Solid는 특정 상황에서 렌더링 횟수를 줄일 수 있는 ", jsx(_components.code, {
        children: "<Index>"
      }), " 컴포넌트도 제공합니다."]
    }), "\n", jsxs(_components.p, {
      children: ["배열이 업데이트 되었을 때, ", jsx(_components.code, {
        children: "<For>"
      }), " 컴포넌트는 참조 동등성을 사용해 요소를 배열의 마지막 상태와 비교합니다. 하지만 이게 항상 원하는 방법은 아닙니다."]
    }), "\n", jsxs(_components.p, {
      children: ["자바스크립트에서 프리미티브(문자열이나 숫자와 같은)는 항상 값으로 비교됩니다. 프리미티브 값이나 배열의 배열에 대해 ", jsx(_components.code, {
        children: "<For>"
      }), "를 사용하는 경우 불필요한 렌더링이 많이 발생할 수 있습니다. 문자열 리스트를 각각 편집 가능한 ", jsx(_components.code, {
        children: "<input>"
      }), " 필드로 매핑하면, 값이 변경될 때마다 ", jsx(_components.code, {
        children: "<input>"
      }), "이 다시 생성됩니다."]
    }), "\n", jsxs(_components.p, {
      children: ["이러한 경우를 위해 ", jsx(_components.code, {
        children: "<Index>"
      }), " 컴포넌트가 제공됩니다. 일반적으로, 프리미티브를 사용하는 경우 ", jsx(_components.code, {
        children: "<Index>"
      }), "를 사용합니다."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Index"
        }), " each={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "cats"
        }), "()}>{", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "cat, i"
          }), ") =>"]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "li"
            }), ">"]
          }), "\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "a"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "target"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"_blank\""
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "href"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "`", jsx(_components.span, {
              className: "hljs-attr",
              children: "https:"
            }), "//", jsx(_components.span, {
              className: "hljs-attr",
              children: "www.youtube.com"
            }), "/", jsx(_components.span, {
              className: "hljs-attr",
              children: "watch"
            }), "?", jsx(_components.span, {
              className: "hljs-attr",
              children: "v"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "${cat().id}"
            }), "`}>"]
          }), "\n      {i + 1}: {cat().name}\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "a"
            }), ">"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "li"
            }), ">"]
          })]
        }), "\n}</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Index"
        }), ">\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["이번에는 항목이 시그널이고, 인덱스가 고정되어 있다는 점만 제외하면 ", jsx(_components.code, {
        children: "<For>"
      }), "와 유사한 시그니처를 가집니다. 각 렌더링된 노드는 배열의 한 지점에 해당합니다. 해당 지점의 데이터가 변경될 때마다, 시그널이 업데이트됩니다."]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "<For>"
      }), "는 배열의 각 데이터 조각에 대해 관심을 가지며, 해당 데이터의 위치가 변경될 수 있습니다. ", jsx(_components.code, {
        children: "<Index>"
      }), "는 배열의 각 인덱스에 관심을 가지며, 각 인덱스의 내용은 변경될 수 있습니다."]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-cedac022.js.map
