import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Solid では、すべてがリアクティブシステムによって左右されるため、ライフサイクル関数はほとんどありません。リアクティブシステムは同期的に作成・更新されるため、唯一のスケジューリングは、更新の最後にプッシュされる Effect になります。"
    }), "\n", jsxs(_components.p, {
      children: ["基本的な作業をしている開発者はこのような考え方をしないことが多いので、少し簡単にするために ", jsx(_components.code, {
        children: "onMount"
      }), " というエイリアスを作りました。", jsx(_components.code, {
        children: "onMount"
      }), " は単なる", jsx(_components.code, {
        children: "createEffect"
      }), " の呼び出しで、非追跡、つまり再実行されません。これは単なる Effect の呼び出しですが、最初のレンダリングがすべて完了した後、コンポーネントに対して一度だけ実行されることを確信して使用できます。"]
    }), "\n", jsxs(_components.p, {
      children: ["それでは、", jsx(_components.code, {
        children: "onMount"
      }), " フックを使って、写真を取得してみましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-keyword",
          children: "async"
        }), " () => {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " res = ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "await"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "fetch"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "`https://jsonplaceholder.typicode.com/photos?_limit=20`"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setPhotos"
        }), "(", jsx(_components.span, {
          className: "hljs-keyword",
          children: "await"
        }), " res.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "json"
        }), "());\n});\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["ライフサイクルはブラウザでしか実行されないので、", jsx(_components.code, {
        children: "onMount"
      }), " にコードを置くことで、SSR 時にサーバー上で実行されないというメリットがあります。この例ではデータのフェッチを行っていますが、通常は真のサーバー/ブラウザ連携のために Solid の Resource を使用します。"]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-e9ea4b50.js.map
